<?php

namespace Koneko\VuexyStoreManager\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Koneko\VuexyAdmin\Models\User;

class StoreWorkCenter extends Model
{
    protected $fillable = [
        'store_id',
        'code',
        'name',
        'description',
        'manager_id',
        'tel',
        'tel2',
        'lat',
        'lng',
        'status',
    ];

    protected $casts = [
        'lat' => 'decimal:6',
        'lng' => 'decimal:6',
        'status' => 'integer',
    ];

    /**
     * Nombre de la etiqueta para generar Componentes
     *
     * @var string
     */
    public $tagName = 'WorkCenter';

    /**
     * Nombre de la columna que contiee el nombre del registro
     *
     * @var string
     */
    public $columnNameLabel = 'name';

    /**
     * Nombre singular del registro.
     *
     * @var string
     */
    public $singularName = 'centro de trabajo';

    /**
     * Nombre plural del registro.
     *
     * @var string
     */
    public $pluralName = 'centros de trabajo';

    /**
     * Relación con la sucursal a la que pertenece el centro de trabajo.
     */
    public function store(): BelongsTo
    {
        return $this->belongsTo(Store::class, 'store_id');
    }

    /**
     * Relación con el usuario que gestiona el centro de trabajo.
     */
    public function manager(): BelongsTo
    {
        return $this->belongsTo(User::class, 'manager_id');
    }
}
