<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('stores', function (Blueprint $table) {
            $table->smallIncrements('id');

            // Información general
            $table->string('code', 16)->unique();
            $table->string('name', 96)->index();
            $table->mediumText('description')->nullable();
            $table->unsignedMediumInteger('manager_id')->nullable()->index(); // sat_codigo_postal.

            // Ubicación
            $table->char('c_pais', 3)->charset('ascii')->collation('ascii_general_ci')->nullable()->index(); // sat_estado.
            $table->unsignedMediumInteger('c_codigo_postal')->nullable()->index(); // sat_codigo_postal.
            $table->string('c_estado', 3)->charset('ascii')->collation('ascii_general_ci')->nullable()->index(); // sat_estado.
            $table->unsignedTinyInteger('c_localidad')->nullable()->index();
            $table->unsignedSmallInteger('c_municipio')->nullable()->index(); // sat_municipio.
            $table->unsignedMediumInteger('c_colonia')->nullable()->index(); // sat_colonia.
            $table->string('direccion')->nullable();
            $table->string('num_ext')->nullable();
            $table->string('num_int')->nullable();
            $table->decimal('lat', 9, 6)->nullable();
            $table->decimal('lng', 9, 6)->nullable();

            // Contacto
            $table->string('email')->nullable();
            $table->string('tel')->nullable();
            $table->string('tel2')->nullable();

            // Información fiscal
            $table->string('rfc', 13)->nullable();
            $table->string('nombre_fiscal')->nullable();
            $table->unsignedSmallInteger('c_regimen_fiscal')->nullable()->index(); // sat_regimen_fiscal.
            $table->unsignedMediumInteger('domicilio_fiscal')->nullable(); // sat_codigo_postal.

            $table->boolean('show_on_website')->default(false)->index();
            $table->boolean('enable_ecommerce')->default(false)->index();

            $table->boolean('status')->default(true)->index();

            // Auditoria
            $table->timestamps(); // Campos created_at y updated_at

            // Relaciones
            $table->foreign('manager_id')->references('id')->on('users')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign('c_regimen_fiscal')->references('c_regimen_fiscal')->on('sat_regimen_fiscal')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign('domicilio_fiscal')->references('c_codigo_postal')->on('sat_codigo_postal')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign('c_pais')->references('c_pais')->on('sat_pais')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign('c_codigo_postal')->references('c_codigo_postal')->on('sat_codigo_postal')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign(['c_estado', 'c_pais'])->references(['c_estado', 'c_pais'])->on('sat_estado')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign(['c_municipio', 'c_estado'])->references(['c_municipio', 'c_estado'])->on('sat_municipio')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign(['c_localidad', 'c_estado'])->references(['c_localidad', 'c_estado'])->on('sat_localidad')->onUpdate('restrict')->onDelete('restrict');
            $table->foreign(['c_colonia', 'c_codigo_postal'])->references(['c_colonia', 'c_codigo_postal'])->on('sat_colonia')->onUpdate('restrict')->onDelete('restrict');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('stores');

    }
};
