<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Query\IndexHint;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    public function up(): void
    {
        Schema::create('email_transactions', function (Blueprint $table) {
            $table->mediumIncrements('id');

            // Relación polimórfica: puede ser un pedido, una factura, etc.
            $table->unsignedMediumInteger('emailable_id')->index();
            $table->string('emailable_type')->index();

            $table->unsignedTinyInteger('email_provider')->index(); // Proveedor en CONST en modelo
            $table->string('smtp_server')->nullable(); // Servidor SMTP personalizado
            $table->string('smtp_port')->nullable(); // Puerto SMTP personalizado
            $table->string('smtp_username')->nullable(); // Nombre de usuario para autenticación SMTP

            $table->string('subject'); // Asunto del correo
            $table->mediumtext('body'); // Cuerpo del correo
            $table->string('recipient'); // Destinatario principal
            $table->json('cc')->nullable(); // Destinatarios en copia (CC), separados por coma
            $table->json('bcc')->nullable(); // Destinatarios en copia oculta (BCC), separados por coma
            $table->string('reply_to')->nullable(); // Dirección de correo para respuestas
            $table->string('sender_name')->nullable(); // Nombre del remitente
            $table->string('sender_email')->nullable(); // Correo electrónico del remitente

            $table->unsignedTinyInteger('status')->index()->comment('0: Pendiente, 1: En proceso, 2: Enviado, 3: Fallido, 4: En cola');

            $table->mediumtext('error_message')->nullable(); // Mensaje de error si el envío falla

            // Authoría
            $table->unsignedMediumInteger('created_by')->index(); // Usuario que creó el registro
            $table->timestamps();

            // Índices
            $table->index(['emailable_type', 'emailable_id']);

            // Auditoría
            $table->foreign('created_by')->references('id')->on('users')->onDelete('restrict');
        });
    }

    public function down(): void
    {
        Schema::dropIfExists('email_transactions');
    }
};
